@@ -42,7 +42,7 @@
 #include "utils.h"
 #include "gconf-keys.h"
 
-#define UNLIKELY_RETURN(thing) G_STMT_START{ if (G_UNLIKELY (!thing)) return; }G_STMT_END
+#define UNLIKELY_RETURN(thing) if (G_UNLIKELY (!(thing))) return;
 
 /* Oh, this one's a fucker. This is one of the few, rare moments where I actually prefer libdbus directly to dbus-glib */
 #define ICD2_STATS_SIGNAL_G_TYPES G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, DBUS_TYPE_G_UCHAR_ARRAY, G_TYPE_UINT, G_TYPE_INT, G_TYPE_UINT, G_TYPE_UINT
@@ -115,19 +115,19 @@ static void wifi_signal_applet_iap_connect_event_cb (ConIcConnection *con G_GNUC
 
 static void wifi_signal_applet_update_image (WifiSignalApplet *plugin, const gchar *text)
 {
-    GdkPixbuf   *new_pix;
-    PangoLayout *layout;
-    cairo_t     *cr;
-    guint16     red, green, blue;
-    gboolean    colour;
+	GdkPixbuf   *new_pix;
+	PangoLayout *layout;
+	cairo_t     *cr;
+	guint16     red, green, blue;
+	gboolean    colour;
 	const PangoFontDescription* pfd = NULL;
 
-    gdk_pixbuf_fill (plugin->priv->pixbuf, 0x00000000);
+	gdk_pixbuf_fill (plugin->priv->pixbuf, 0x00000000);
 
-    cr = pixbuf_cairo_create (plugin->priv->pixbuf);
-    colour = he_helper_get_logical_font_colour ("DefaultTextColor", &red, &green, &blue);
-    if (colour)
-    	cairo_set_source_rgb (cr, red, green, blue);
+	cr = pixbuf_cairo_create (plugin->priv->pixbuf);
+	colour = he_helper_get_logical_font_colour ("DefaultTextColor", &red, &green, &blue);
+	if (colour)
+		cairo_set_source_rgb (cr, red, green, blue);
 	else
 		cairo_set_source_rgb (cr, 0, 0, 0);
 
@@ -145,7 +145,7 @@ static void wifi_signal_applet_update_image (WifiSignalApplet *plugin, const gch
 	new_pix = pixbuf_cairo_destroy (cr, FALSE);
 	g_object_unref (new_pix);
 
-    hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (plugin), plugin->priv->pixbuf);
+	hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (plugin), plugin->priv->pixbuf);
 }
 
 /* Where it all falls down */
@@ -196,7 +196,8 @@ static void wifi_signal_applet_finalize (GObject *object)
 
 	g_signal_handlers_disconnect_by_func (plugin, G_CALLBACK (wifi_signal_applet_status_area_visible_cb), NULL);
 
-	G_OBJECT_CLASS (wifi_signal_applet_parent_class)->finalize (object);
+	if (G_OBJECT_CLASS (wifi_signal_applet_parent_class)->finalize)
+		G_OBJECT_CLASS (wifi_signal_applet_parent_class)->finalize (object);
 }
 
 /* -- */
@@ -211,9 +212,10 @@ static gboolean wifi_signal_applet_send_stats_req (WifiSignalApplet *plugin)
 static void wifi_signal_applet_remove_timeout (WifiSignalApplet *plugin)
 {
 	if (plugin->priv->timeout_src)
+	{
 		g_source_destroy (g_main_context_find_source_by_id (NULL, plugin->priv->timeout_src));
-	
-	plugin->priv->timeout_src = 0;
+		plugin->priv->timeout_src = 0;
+	}
 }
 
 static void wifi_signal_applet_add_timeout (WifiSignalApplet *plugin)
@@ -243,7 +245,7 @@ static void wifi_signal_applet_on_stats_rec_cb (DBusGProxy *object G_GNUC_UNUSED
 
 static void wifi_signal_applet_iap_connect_event_cb (ConIcConnection *con G_GNUC_UNUSED, ConIcConnectionEvent *e, WifiSignalApplet *plugin)
 {
-	plugin->priv->iap_connected = con_ic_connection_event_get_status (e) == CON_IC_STATUS_CONNECTED;
+	plugin->priv->iap_connected = con_ic_connection_event_get_status (e) == CON_IC_STATUS_CONNECTED && g_str_equal (con_ic_event_get_bearer_type (CON_IC_EVENT (e)), CON_IC_BEARER_WLAN_INFRA);
 	if (plugin->priv->iap_connected)
 		(void) wifi_signal_applet_send_stats_req (plugin);
 
@@ -303,7 +305,7 @@ static void wifi_signal_applet_constructed (GObject *object)
 	}
 
 	g_signal_connect (plugin, "notify::status-area-visible", G_CALLBACK (wifi_signal_applet_status_area_visible_cb), NULL);
-	g_object_notify (G_OBJECT (plugin), "status-area-visible");
+	g_object_get (plugin, "status-area-visible", &plugin->priv->is_status_area_visible, NULL);
 
 	dbus_g_proxy_add_signal (plugin->priv->icd2_proxy, ICD_DBUS_API_STATISTICS_SIG, ICD2_STATS_SIGNAL_G_TYPES, G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (plugin->priv->icd2_proxy, ICD_DBUS_API_STATISTICS_SIG, G_CALLBACK (wifi_signal_applet_on_stats_rec_cb), plugin, NULL);
